-- Testna struktura za generator tonov
-- Vrsta datoteke: VHDL 2008

library IEEE, STD;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.numeric_std.ALL;
use STD.textio.all;

entity TestGenerator is
end TestGenerator;

architecture Behavioral of TestGenerator is

component generator
 port(
   clk : in std_logic;
   n : in unsigned(2 downto 0);
   pulz : out std_logic
 );
end component;

 signal clk : std_logic:= '0';
 signal n : unsigned(2 downto 0);
 signal pulz : std_logic;
 
 constant T : time := 20 ns;      -- 50 MHz
 signal endsim: boolean := false;
begin

uut: generator port map (
     clk => clk,
     n => n,
     pulz => pulz
);

endsim <= true after 15 ms;   -- simulacijo izvajaj 15 ms

n <= "000", "001" after 1 ms; -- nastavi vhod

clk_gen: process -- ura periode T
begin
 if not endsim then
  clk <= '1';  wait for T/2; 
  clk <= '0';  wait for T/2;
 else
  wait;
 end if;
end process;

meri: process -- meri frekvenco pulzov
 variable t0, t1 : time := 0 ns;
 variable p: integer;
 variable f: real;
begin
 wait until rising_edge(pulz);
 t1 := now - t0;
 t0 := now;
 p := (t1 / 1 us); -- perioda v us
 if p /= 0 then
  f := (1000000.0 / real(p)); 
  write(output, "F = "& to_string(f, "%.1f") & " Hz" & LF);
 end if;
end process;

end Behavioral;